# README - ResourceManager

Version 3

## Overview

This is a compiled version of the SpriteResourceManager that has
functionality to manage Sprites as part of the Resource Manager from
the [Dragonfly Book](https://dragonfly.wpi.edu/), version 6.

To be used, the SpriteResourceManager *must* be accompanied by
implementations for Dragonfly Naiad (i.e., up to Development
Checkpoint #7).  In addition, the following classes are needed:

+ Color: `Color.h`
+ Frame: `Frame.h` and `Frame.cpp`
+ Sprite: `Sprite.h` and `Sprite.cpp`

See Section 4.12 of the book for details.

Then, upon reaching Development Checkpoint #8, step #5:

+ ResourceManager: `ResourceManager.h`

should be derived from SpriteResourceManager:

```c++
// ResourceManager.h

class ResourceManager : public SpriteResourceManager {
   ...
};
```

## Files

Platforms, organized by directory:

- windows
- linux
- mac

Relevant files under each directory:

- `SpriteResourceManager.o` or `SpriteResourceManager.obj` - the compiled manager
- `SpriteResourceManager.h` - the header file

In addition, there is a directory

- sprites/

that contains sprites (some with errors) for testing (see below).

## Install

Linux/Mac: Copy the `.o` and `.h` files appropriate to your platform
to your project directory as well as the `sprites/` directory and its
contents.

Windows: Right click on your project in the Solution Explorer window,
select "Add" -> "Existing Item" and choose both
`SpriteResourceManager.obj` and `SpriteResourceManager.h`.

## Testing

After building all necessary classes, test by using the test sprites
and the following code:

```c++
// Engine includes.
#include "LogManager.h"
#include "ResourceManager.h"

int main(int argc, char *argv[]) {

  // Start up LogManager.
  if (LM.startUp())  {
    LM.writeLog("main(): Error starting log manager!");
    return 1;
  }
  
  // Start up ResourceManager.
  if (RM.startUp())  {
    LM.writeLog("main(): Error starting resource manager!");
    return 1;
  }

  // Load good sprite.
  if (RM.loadSprite("sprites/good-spr.txt", "good") != 0)
    LM.writeLog("main(): Error loading good sprite!");
  else
    LM.writeLog("main(): Successfully loaded good sprite.");

  // Load bad sprite.
  if (RM.loadSprite("sprites/bad-spr.txt", "bad") == 0)
    LM.writeLog("main(): Loaded bad sprite, but should not have!");
  else
    LM.writeLog("main(): Correctly did not load bad sprite.");

  // Shut everything down.
  RM.shutDown();
  LM.shutDown();

  return 0;
}
```

After compiling and running, you should find a file named
`dragonfly.log` file with:

````
LM::startUp(): Successfully started.
SRM::startUp(): Successfully started.
RM::startUp(): Successfully started.
SRM::loadSprite(): Loading sprite 'sprites/good-spr.txt'.
SRM::loadSprite(): Opened file 'sprites/good-spr.txt'.
	      Frames: 5
	       Width: 6
	      Height: 2
	    Slowdown: 4
	       Color: green
SRM::loadSprite(): Sprite 'good' loaded.
main(): Successfully loaded good sprite.
SRM::loadSprite(): Loading sprite 'sprites/bad-spr.txt'.
SRM::loadSprite(): Opened file 'sprites/bad-spr.txt'.
SRM::loadSprite(): Warning! No 'color' in header.
SRM::loadSprite(): Warning! No 'slowdown' in header.
	      Frames: 2
	       Width: 4
	      Height: 2
	    Slowdown: 0
	       Color: default
	Error! Line 10: No more frame data.
SRM::loadSprite(): Error! No frame data to add.
SRM::loadSprite(): Sprite 'bad' not loaded.
main(): Correctly did not load bad sprite.
SRM::shutDown(): Successfully stopped.
RM::shutDown(): Successfully stopped.
LM::shutDown(): Successfully stopped.
````

## Next

Use in implementing your fully functional, full-featured game engine.

Happy resource managing!

-- Mark, `claypool@cs.wpi.edu`
